@@ -1,23 +1,22 @@
 package GNUpod::QTfile;
 
-#  Copyright (C) 2003-2004 Adrian Ulrich <pab at blinkenlights.ch>
+#  Copyright (C) 2003-2007 Adrian Ulrich <pab at blinkenlights.ch>
 #  Part of the gnupod-tools collection
 #
 #  URL: http://www.gnu.org/software/gnupod/
 #
-#    This program is free software; you can redistribute it and/or modify
+#    GNUpod is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
-#    the Free Software Foundation; either version 2 of the License, or
+#    the Free Software Foundation; either version 3 of the License, or
 #    (at your option) any later version.
 #
-#    This program is distributed in the hope that it will be useful,
+#    GNUpod is distributed in the hope that it will be useful,
 #    but WITHOUT ANY WARRANTY; without even the implied warranty of
 #    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 #    GNU General Public License for more details.
 #
 #    You should have received a copy of the GNU General Public License
-#    along with this program; if not, write to the Free Software
-#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#    along with this program.  If not, see <http://www.gnu.org/licenses/>.#
 #
 # iTunes and iPod are trademarks of Apple
 #
@@ -34,7 +33,17 @@ use strict;
 use GNUpod::FooBar;
 use vars qw(%hchild %reth @LEVELA);
 
+#Define handler items
 use constant SOUND_ITEM => 'soun';
+use constant VIDEO_ITEM => 'vide';
+
+
+#Mediatypes for the iPod
+use constant MEDIATYPE_VIDEO => 0x02;
+use constant MEDIATYPE_AUDIO => 0x01;
+
+#Do not kill the host by allocating toomuch memory
+use constant MAX_RSEEK_DATA => 1024*1024;
 
 #Some static def
 $hchild{'moov'} = 8;
@@ -79,7 +88,6 @@ sub parsefile {
 	my $level = 1;
 	my %lx = ();
 	   %reth = (); #Cleanup
-
 	if($fsize < 16 || rseek(4,4) ne "ftyp") { #Can't be a QTfile
 		close(QTFILE);
 		return undef;
@@ -105,15 +113,25 @@ sub parsefile {
  
 ########### Now we build the chain #######################################
 
-#Search the Sound-Stream
-my $sound_index = get_sound_index($lx{metadat}{'::moov::trak::mdia::hdlr'});
+my $video_index = get_media_index($lx{metadat}{'::moov::trak::mdia::hdlr'}, VIDEO_ITEM);
+my $sound_index = get_media_index($lx{metadat}{'::moov::trak::mdia::hdlr'}, SOUND_ITEM);
 
-if($sound_index < 0) {
- warn "QTfile.pm: No 'sound' data found in file!\n";
- return undef;
+
+if($video_index >= 0 && $sound_index >= 0) {
+	#This looks like a video
+	$reth{mediatype} = MEDIATYPE_VIDEO;
+}
+elsif($sound_index >= 0) {
+	#..only sound
+	$reth{mediatype} = MEDIATYPE_AUDIO;
+}
+else {
+	warn "QTfile.pm: No sound/video stream found in file!\n";
+	return undef;
 }
 
-#print "::moov::trak::mdia::hdlr  -> $sound_index\n";
+
+
 
 my @METADEF = ("album",   "\xA9alb",
                "comment", "\xA9cmt",
@@ -133,6 +151,7 @@ my @METADEF = ("album",   "\xA9alb",
    $reth{$METADEF[$i]} = $lx{metadat}{$cKey}[$sound_index];
   }
  }
+ 
 
 ###INT and such fields are here:
  
@@ -151,12 +170,17 @@ my @METADEF = ("album",   "\xA9alb",
  }
  
 
- if( my $cDat = $lx{metadat}{'::moov::mvhd'}[$sound_index] ) {
- #Calculate the time... 
- $reth{time} = int( get_string_oct(8,4,$cDat)/
-                    get_string_oct(4,4,$cDat)*1000 );
+#Search for a TIME index: first sound, then video
+ foreach my $cidentify ( ($sound_index, $video_index) ) {
+  next if $cidentify < 0; #Invalid identifyer
+  if( my $cDat = ( $lx{metadat}{'::moov::mvhd'}[$cidentify] or $lx{metadat}{'::moov::trak::mdia::mdhd'}[$cidentify]) ) {
+   #Calculate the time... 
+   $reth{time} = int( get_string_oct(8,4,$cDat)/
+                      get_string_oct(4,4,$cDat)*1000 );
+   last if $reth{time};
+  }
  }
- 
+
 
  if($lx{metadat}{'::moov::udta::meta::ilst::----::mean'}[$sound_index] eq "apple.iTunes" &&
     $lx{metadat}{'::moov::udta::meta::ilst::----::name'}[$sound_index] eq "NORM") {
@@ -196,6 +220,7 @@ sub get_atom {
 	#..and keep track of it..
 	$level = $lt->{ltrack}->{$pos} if $lt->{ltrack}->{$pos};
 	
+	
 	#Build a chain for this level.. looks like '::foo::bar::bla'
 	$LEVELA[$level] = $typ;
 	my $cChain = undef;
@@ -220,12 +245,13 @@ sub get_atom {
 
 ############################################
 # Search the 'soun' item
-sub get_sound_index {
-	my($ref) = @_;
+sub get_media_index {
+	my($ref,$rq) = @_;
+	die "get_media_index($ref,$rq): Assert length(\$rq)==4 failed\n" unless length($rq) == 4;
 	my $sid = 0;
 	my $sound_index = -1;
 	foreach(@$ref) {
-		if( substr($_,0,4) eq SOUND_ITEM ) {
+		if( substr($_,0,4) eq $rq) {
 			$sound_index = $sid;
 			last;
 		}
@@ -260,6 +286,15 @@ sub get_string_oct {
 sub rseek {
 	my($offset, $len) = @_;
 	return undef if $len < 0;
+	
+	if($len < 0) {
+		warn "QTFile.pm: rseek($offset,$len) : POSSIBLE BUG OR BROKEN FILE: Calling rseek with \$len == 0 isn't such a good idea?!\n";
+	}
+	elsif($len > MAX_RSEEK_DATA) {
+		warn "QTFile.pm: rseek($offset,$len) : POSSIBLE BUG OR BROKEN FILE: Ouch! rseek refuses to return $len bytes; Request cropped to ".MAX_RSEEK_DATA."\n";
+		$len = MAX_RSEEK_DATA;
+	}
+	
 	my $buff;
 	seek(QTFILE, $offset, 0);
 	read(QTFILE, $buff, $len);
