@@ -214,8 +214,9 @@ sub mk_itunes_sd_file {
 	my $ret = undef;
 
 	#The Shuffle needs / , not :
-	$ref->{path} =~ tr/:/\//;
-	my $uc = new Unicode::String($ref->{path});
+	my $path = $ref->{path};
+	$path =~ tr/:/\//;
+	my $uc = new Unicode::String($path);
 	
 	$ret .= tnp(0x00022E);	#Static?
 	$ret .= tnp(0x5AA501);	#unk1
@@ -229,10 +230,10 @@ sub mk_itunes_sd_file {
 	
 	## This is ugly!
 	my $fixmetype = 1; #MP3
-	if($ref->{path} =~ /\.m4.$/i) {
+	if($path =~ /\.m4.$/i) {
 		$fixmetype = 2;
 	}
-	elsif($ref->{path} =~ /\.wav$/i) {
+	elsif($path =~ /\.wav$/i) {
 		$fixmetype = 4;
 	}
 
@@ -265,15 +266,17 @@ sub mk_mhbd {
 	my ($hr) = @_;
 
 	my $ret = "mhbd";
-	   $ret .= pack("V", 104);                        #Header Size
-	   $ret .= pack("V", _icl($hr->{size}+104));      #Size of whole mhdb
+	   $ret .= pack("V", 320);                        #Header Size
+	   $ret .= pack("V", _icl($hr->{size}+320));      #Size of whole mhdb
 	   $ret .= pack("V", 0x1);                        #?
-	   $ret .= pack("V", 0xC);                        # Version, we are iTunes 4.7 -> 12
+	   $ret .= pack("V", 0x19);                       # Version, we are iTunes 7.4.2 -> 0x19
 	   $ret .= pack("V", _icl($hr->{childs}));        # Childs, currently always 2
 	   $ret .= pack("V", 0xE0ADECAD);                 # UID -> 0xA_Decade_0f_bad_f00d
 	   $ret .= pack("V", 0x0DF0ADFB);
 	   $ret .= pack("V", 0x2);                        #?
-	   $ret .= pack("V17", "00");                     #dummy space
+	   $ret .= pack("V3", "00");
+		 $ret .= pack("V",  "00");                      # 0x30 Hash58 will set this to 1
+	   $ret .= pack("V67", "00");                     #dummy space
 return $ret;
 }
 
@@ -340,7 +343,7 @@ sub mk_mhit {
     $ret .= pack("V", _icl(1));                             #Visible?
     $ret .= pack("V");                                      #FileType. Should be 'MP3 '. (FIXME: Extension or type?)
     $ret .= pack("v", 0x100);                               #cbr = 100, vbr = 101, aac = 0x010 ##FIXME: COrrect?
-    $ret .= pack("c", (($file_hash{compilation})==0));      #compilation ?
+    $ret .= pack("c", (($file_hash{compilation})!=0));      #compilation
     $ret .= pack("c",$file_hash{rating});                   #rating
     $ret .= pack("V", _icl($file_hash{changetime}));        #Time changed
     $ret .= pack("V", _icl($file_hash{filesize}));          #filesize
@@ -1141,7 +1144,7 @@ my %ret     = ();
 $ret{id}         = get_int($sum+16,4,$fd);
 #$ret{rating}     = int((get_int($sum+28,4)-256)/oct('0x14000000')) * 20;
 ##XXX 26-30 are useless for us..
-$ret{compilation}= (get_int($sum+30,1,$fd)==0);
+$ret{compilation}= (get_int($sum+30,1,$fd)!=0);
 $ret{rating}     = get_int($sum+31,1,$fd);
 $ret{changetime} = get_int($sum+32,4,$fd);
 $ret{filesize}   = get_int($sum+36,4,$fd);
