@@ -1,22 +1,21 @@
 ###__PERLBIN__###
-#  Copyright (C) 2002-2004 Adrian Ulrich <pab at blinkenlights.ch>
+#  Copyright (C) 2002-2007 Adrian Ulrich <pab at blinkenlights.ch>
 #  Part of the gnupod-tools collection
 #
 #  URL: http://www.gnu.org/software/gnupod/
 #
-#    This program is free software; you can redistribute it and/or modify
+#    GNUpod is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
-#    the Free Software Foundation; either version 2 of the License, or
+#    the Free Software Foundation; either version 3 of the License, or
 #    (at your option) any later version.
 #
-#    This program is distributed in the hope that it will be useful,
+#    GNUpod is distributed in the hope that it will be useful,
 #    but WITHOUT ANY WARRANTY; without even the implied warranty of
 #    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 #    GNU General Public License for more details.
 #
 #    You should have received a copy of the GNU General Public License
-#    along with this program; if not, write to the Free Software
-#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#    along with this program.  If not, see <http://www.gnu.org/licenses/>.#
 #
 # iTunes and iPod are trademarks of Apple
 #
@@ -33,7 +32,7 @@ print "gnupod_INIT.pl ###__VERSION__### (C) Adrian Ulrich\n";
 
 $opts{mount} = $ENV{IPOD_MOUNTPOINT};
 #Don't add xml and itunes opts.. we *NEED* the mount opt to be set..
-GetOptions(\%opts, "version", "help|h", "mount|m=s", "disable-convert|d", "france|f");
+GetOptions(\%opts, "version", "help|h", "mount|m=s", "disable-convert|d", "france|f", "noask");
 #gnupod_INIT does not read configuration files!
 
 usage() if $opts{help};
@@ -72,7 +71,7 @@ Hit ENTER to continue or CTRL+C to abort
 EOF
 ##
 
-<STDIN>;
+<STDIN> unless $opts{noask};
  
  print "Creating directory structure on $opts{mount}\n\n";
  print "> AppFolders:\n";
@@ -116,12 +115,12 @@ EOF
  if(-e $con->{itunesdb} && !$opts{'disable-convert'}) {
  #We have an iTunesDB, call tunes2pod.pl
   print "Found *existing* iTunesDB, running tunes2pod.pl\n";
-  $t2pfail = system("$con->{bindir}/tunes2pod.pl --force -m $opts{mount}");
+  $t2pfail = system("$con->{bindir}/tunes2pod.pl", "--force", "-m", $opts{mount});
  }
  else {
  #No iTunesDB, run mktunes.pl
   print "No iTunesDB found, running mktunes.pl\n";
-  $t2pfail = system("$con->{bindir}/mktunes.pl -m $opts{mount}");
+  $t2pfail = system("$con->{bindir}/mktunes.pl", "-m" ,"$opts{mount}");
  }
  
  if($t2pfail) {
@@ -153,6 +152,7 @@ Usage: gnupod_INIT.pl [-h] [-m directory]
                            Firmware 1.x (1st & 2nd generation)
                            You can also use mktunes.pl '--volume PERCENT'
                            to adjust the volume (Works with Firmware 1.x AND 2.x)
+       --noask             Do not wait for any user input
 
 Report bugs to <bug-gnupod\@nongnu.org>
 EOF
