@@ -1,29 +1,29 @@
 ###__PERLBIN__###
-#  Copyright (C) 2002-2005 Adrian Ulrich <pab at blinkenlights.ch>
+#  Copyright (C) 2002-2007 Adrian Ulrich <pab at blinkenlights.ch>
 #  Part of the gnupod-tools collection
 #
 #  URL: http://www.gnu.org/software/gnupod/
 #
-#    This program is free software; you can redistribute it and/or modify
+#    GNUpod is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
-#    the Free Software Foundation; either version 2 of the License, or
+#    the Free Software Foundation; either version 3 of the License, or
 #    (at your option) any later version.
 #
-#    This program is distributed in the hope that it will be useful,
+#    GNUpod is distributed in the hope that it will be useful,
 #    but WITHOUT ANY WARRANTY; without even the implied warranty of
 #    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 #    GNU General Public License for more details.
 #
 #    You should have received a copy of the GNU General Public License
-#    along with this program; if not, write to the Free Software
-#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#    along with this program.  If not, see <http://www.gnu.org/licenses/>.#
 #
 # iTunes and iPod are trademarks of Apple
 #
 # This product is not supported/written/published by Apple!
 
 use strict;
-
+use GNUpod::FooBar;
+use GNUpod::FileMagic;
 
 
 my $file  = $ARGV[0] or exit(1);
@@ -58,10 +58,11 @@ elsif($gimme eq "GET_META") {
 	print "_TRACKNUM:$ftag->{TRACKNUMBER}\n";
 	print "_COMMENT:$ftag->{COMMENT}\n";
 	print "_VENDOR:$ftag->{VENDOR}\n";
+	print "_MEDIATYPE:".(GNUpod::FileMagic::MEDIATYPE_AUDIO)."\n";
 	print "FORMAT: FLAC\n";
 }
 elsif($gimme eq "GET_PCM") {
-	my $tmpout = get_u_path("/tmp/gnupod_pcm", "wav");
+	my $tmpout = GNUpod::FooBar::get_u_path("/tmp/gnupod_pcm", "wav");
 	my $status = system("flac", "-d", "-s", "$file", "-o", $tmpout);
 	if($status) {
 		warn "flac exited with $status, $!\n";
@@ -73,7 +74,7 @@ elsif($gimme eq "GET_PCM") {
 elsif($gimme eq "GET_MP3") {
 	#Open a secure flac pipe and open anotherone for lame
 	#On errors, we'll get a BrokenPipe to stout
-	my $tmpout = get_u_path("/tmp/gnupod_mp3", "mp3");
+	my $tmpout = GNUpod::FooBar::get_u_path("/tmp/gnupod_mp3", "mp3");
 	open(FLACOUT, "-|") or exec("flac", "-d", "-s", "-c", "$file") or die "Could not exec flac: $!\n";
 	open(LAMEIN , "|-") or exec("lame", "-V", $quality, "--silent", "-", $tmpout) or die "Could not exec lame: $!\n";
 	while(<FLACOUT>) {
@@ -85,8 +86,8 @@ elsif($gimme eq "GET_MP3") {
 }
 elsif($gimme eq "GET_AAC" or $gimme eq "GET_AACBM") {
 	#Yeah! FAAC is broken and can't write to stdout..
-	my $tmpout = get_u_path("/tmp/gnupod_faac", "m4a");
-	   $tmpout = get_u_path("/tmp/gnupod_faac", "m4b") if $gimme eq "GET_AACBM";
+	my $tmpout = GNUpod::FooBar::get_u_path("/tmp/gnupod_faac", "m4a");
+	   $tmpout = GNUpod::FooBar::get_u_path("/tmp/gnupod_faac", "m4b") if $gimme eq "GET_AACBM";
 	$quality = 140 - ($quality*10);
 	open(FLACOUT, "-|") or exec("flac", "-d", "-s", "-c", "$file") or die "Could not exec flac: $!\n";
 	open(FAACIN , "|-") or exec("faac", "-w", "-q", $quality, "-o", $tmpout, "-") or die "Could not exec faac: $!\n";
@@ -105,13 +106,3 @@ else {
 
 exit(0);
 
-#############################################
-# Get Unique path
-sub get_u_path {
-	my($prefix, $ext) = @_;
-	my $dst = undef;
-	while($dst = sprintf("%s_%d_%d.$ext",$prefix, int(time()), int(rand(99999)))) {
-		last unless -e $dst;
-	}
-	return $dst;
-}
